AngleUnit class sealed

A physical angle that can be converted without a rendering context.

Inheritance
Implementers

Properties

canonical String
A deterministic authoring representation of this unit.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
The canonical suffix for this unit.
no setterinherited
value double
Numeric magnitude of this unit.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDegrees() Degrees
Converts this angle to degrees.
toRadians() Radians
Converts this angle to radians.
toString() String
A string representation of this object.
inherited
toTurns() Turns
Converts this angle to turns.

Operators

operator ==(Object other) bool
The equality operator.
inherited