Milliseconds class final
A duration expressed in milliseconds.
Constructors
- Milliseconds(double value)
-
Creates a millisecond value.
const
Properties
- canonical → String
-
A deterministic authoring representation of this unit.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
The canonical suffix for this unit.
no setteroverride
- value → double
-
Numeric magnitude of this unit.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDuration(
) → Duration -
Converts this value to Duration, rounding to the nearest microsecond.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited